@@ -24,6 +24,8 @@
 #ifndef GNOKII_GCONF_H
 #define GNOKII_GCONF_H
 
-gchar ** getGnokiiCfg(gerror **error);
+#include <glib.h> 
+
+gchar ** getGnokiiCfg(GError **error);
 
 #endif
